.. _how_to:

How to
======

In here you will find recipes on how to use icclim to solve specific problems.

To grasp the basic usage of icclim, you may consider following :ref:`tutorials` first.
To find more in depth technical knowledge see :ref:`references`.

.. toctree::
    :maxdepth: 2
    :caption: How to

    Chunk data and parallelize computation <dask>
    Run our jupyter notebooks <notebooks>
    Compute ECA&D indices <recipes_ecad>
    Create customized indices <recipes_custom>
    Use icclim through OCGIS <ocgis>
